# frozen_string_literal: true
require 'flakyci_rspec/environments'
require "http"

MUTATION = "
mutation exUnitResults($build: RspecBuild!, $project_key: UUID4!, $version: Int!) {
	rspecResults(build: $build, projectKey: $project_key, version: $version){
    slug
    text
  }
}
"

class FlakyciRspec
  RSpec::Core::Formatters.register self, :seed, :dump_summary, :close

  def initialize(_output)
    @output = ''
    @env = Environments.new()
  end

  def seed(seed)
    @seed = seed.seed
  end

  def dump_summary(notification)
    results = notification.examples.map do |example|
      location = example.location.split(':')

      {
        module: example.example_group,
        name: example.description,
        line: location[1],
        file: location[0],
        status: example.execution_result.status,
        duration: (example.execution_result.run_time * 1000).round
      }
    end
    build = @env.get_env()
    build[:suite] = {
      seed: @seed,
      results: results
    }
    print(project_key())
    variables = {
      build: build,
      version: 1,
      project_key: project_key()
    }  
    res = HTTP.post(url(), :json => {query: MUTATION, variables: variables})
    res = JSON.parse(res)
    if res["errors"]
      print(res["errors"][0]["message"])
    end
  end

  def close(_notification)
    @output
  end

  def project_key
    ENV["FLAKYCI_KEY"] 
  end

  def url
    ENV["FLAKYCI_URL"] || "https://www.flakyci.com/api"
  end
end
